@@ -1,3 +1,4 @@
+import asyncio
 from typing import Union, Mapping, TYPE_CHECKING, Dict, Any, TypeVar, List, Type
 
 from pydantic import BaseModel
@@ -46,7 +47,7 @@ class OrmModelMeta(ModelMetaclass):
         cls = super().__new__(mcs, name, bases, new_namespace, **kwargs)
         cls._ensure_proper_init()
         cls.c = cls.__sqla_table__.c
-        cls.__exclude__ = EXCLUDE_KEYS.copy() | exclude | {'id'}
+        cls.__exclude__ = EXCLUDE_KEYS.copy() | exclude
         cls.__relations__ = relation_namespace
         return cls
 
@@ -70,7 +71,7 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
     def _init_private_attributes(self):
         self.__modified__ = set()
         self.__bound__ = False
-        for k, v in self.__relations__.items():
+        for k, v in self.__relations__.items():  # pylint: disable=no-member
             self.__dict__[k] = v._init_copy(self)  # pylint: disable=protected-access
         super()._init_private_attributes()
 
@@ -87,7 +88,7 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
               include: Union['AbstractSetIntStr', 'MappingIntStrAny'] = None,
               exclude: Union['AbstractSetIntStr', 'MappingIntStrAny'] = None, exclude_unset: bool = False,
               exclude_defaults: bool = False, exclude_none: bool = False) -> 'TupleGenerator':
-        exclude_private = self.__exclude__ - {'id'} | EXCLUDE_KEYS
+        exclude_private = self.__exclude__ | EXCLUDE_KEYS
         if exclude is None:
             exclude = exclude_private
         elif isinstance(exclude, Mapping):  # pylint: disable=isinstance-second-argument-not-valid-type
@@ -106,6 +107,8 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
             return object.__setattr__(self, name, value)
         if name not in self.__private_attributes__:
             self.flag_modified(name)
+        if name in self.__relations__:
+            raise ValueError('Do not set relation field')
         return super().__setattr__(name, value)
 
     @classmethod
@@ -143,6 +146,8 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
             data = self.dict(exclude={'id'})
             if len(data) == 0:
                 data['id'] = None
+            if self.id is not None:
+                data['id'] = self.id
             self.id = await FoxOrm.db.execute(table.insert(), data)  # pylint: disable=attribute-defined-outside-init
             self.__bound__ = True
 
@@ -220,16 +225,15 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
     async def get(cls: Type[MODEL], obj_id: int, skip_parsing=False) -> MODEL:
         return await cls.select(cls.__sqla_table__.c.id == obj_id, skip_parsing=skip_parsing)
 
-    async def _fetch_related(self, field: str):
-        self.ensure_id()
-        relation: _GenericIterableRelation = getattr(self, field)
-        if not isinstance(relation, _GenericIterableRelation):
-            raise OrmException('fetch_related argument is not a relation')
-        await relation.fetch()
-
     async def fetch_related(self, *fields: str) -> None:
+        self.ensure_id()
+        tasks = []
         for field in fields:
-            await self._fetch_related(field)
+            relation: _GenericIterableRelation = getattr(self, field)
+            if not isinstance(relation, _GenericIterableRelation):
+                raise OrmException('fetch_related argument is not a relation')
+            tasks.append(relation.fetch())
+        await asyncio.gather(*tasks)
 
 
 __all__ = ['OrmModel']
